loggers

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 19, 2024 License: MIT Imports: 6 Imported by: 1

Documentation

Index

Constants

const CIEnv = "CI"

Variables

This section is empty.

Functions

func NewTerminal

func NewTerminal() quicklog.Logger

NewTerminal creates a new Logger that logs to the terminal.

func NewZerolog

func NewZerolog(logger zerolog.Logger) quicklog.Logger

NewZerolog creates a new logger using the zerolog library.

Types

This section is empty.

Jump to